@@ -17,7 +17,6 @@ from auto_editor.utils.types import (
     sample_rate,
     speed,
     speed_range,
-    time,
     time_range,
 )
 from auto_editor.validate_input import valid_input
@@ -34,24 +33,6 @@ def main_options(parser: ArgumentParser) -> ArgumentParser:
         metavar="LENGTH",
         help='Set sections near "loud" as "loud" too if section is less than LENGTH away.',
     )
-    parser.add_argument(
-        "--min-clip-length",
-        "--min-clip",
-        "-minclip",
-        "-mclip",
-        type=time,
-        metavar="LENGTH",
-        help="Set the minimum length a clip can be. If a clip is too short, cut it",
-    )
-    parser.add_argument(
-        "--min-cut-length",
-        "--min-cut",
-        "-mincut",
-        "-mcut",
-        type=time,
-        metavar="LENGTH",
-        help="Set the minimum length a cut can be. If a cut is too short, don't cut",
-    )
     parser.add_argument(
         "--edit-based-on",
         "--edit",
@@ -225,7 +206,10 @@ def main_options(parser: ArgumentParser) -> ArgumentParser:
     )
     parser.add_argument("--debug", flag=True, help="Show debugging messages and values")
     parser.add_argument(
-        "--show-ffmpeg-debug", flag=True, help="Show ffmpeg progress and output"
+        "--show-ffmpeg-commands", flag=True, help="Show ffmpeg commands"
+    )
+    parser.add_argument(
+        "--show-ffmpeg-output", flag=True, help="Show ffmpeg stdout and stderr"
     )
     parser.add_argument("--quiet", "-q", flag=True, help="Display less output")
     parser.add_argument(
@@ -296,7 +280,7 @@ def main_options(parser: ArgumentParser) -> ArgumentParser:
 
 
 def main() -> None:
-    subcommands = ("test", "info", "levels", "grep", "subdump", "desc", "repl")
+    subcommands = ("test", "info", "levels", "subdump", "desc", "repl", "palet")
 
     if len(sys.argv) > 1 and sys.argv[1] in subcommands:
         obj = __import__(
@@ -304,27 +288,32 @@ def main() -> None:
         )
         obj.main(sys.argv[2:])
         sys.exit()
-    else:
-        args = main_options(ArgumentParser("Auto-Editor")).parse_args(
-            Args,
-            sys.argv[1:],
-            macros=[
-                ({"--frame-margin"}, ["--margin"]),
-                ({"--export-to-premiere", "-exp"}, ["--export", "premiere"]),
-                ({"--export-to-final-cut-pro", "-exf"}, ["--export", "final-cut-pro"]),
-                ({"--export-to-shotcut", "-exs"}, ["--export", "shotcut"]),
-                ({"--export-as-json"}, ["--export", "json"]),
-                ({"--export-as-clip-sequence", "-excs"}, ["--export", "clip-sequence"]),
-                ({"--keep-tracks-seperate"}, ["--keep-tracks-separate"]),
-            ],
-        )
+
+    args = main_options(ArgumentParser("Auto-Editor")).parse_args(
+        Args,
+        sys.argv[1:],
+        macros=[
+            ({"--frame-margin"}, ["--margin"]),
+            ({"--export-to-premiere", "-exp"}, ["--export", "premiere"]),
+            ({"--export-to-final-cut-pro", "-exf"}, ["--export", "final-cut-pro"]),
+            ({"--export-to-shotcut", "-exs"}, ["--export", "shotcut"]),
+            ({"--export-as-json"}, ["--export", "json"]),
+            ({"--export-as-clip-sequence", "-excs"}, ["--export", "clip-sequence"]),
+            ({"--keep-tracks-seperate"}, ["--keep-tracks-separate"]),
+        ],
+    )
 
     if args.version:
         print(f"{auto_editor.version} ({auto_editor.__version__})")
         sys.exit()
 
     log = Log(args.debug, args.quiet)
-    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, args.show_ffmpeg_debug)
+    ffmpeg = FFmpeg(
+        args.ffmpeg_location,
+        args.my_ffmpeg,
+        args.show_ffmpeg_commands,
+        args.show_ffmpeg_output,
+    )
 
     if args.debug and args.input == []:
         import platform as plat
