@@ -4,20 +4,13 @@ import os
 from typing import Any
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
-from auto_editor.objs.export import (
-    ExAudio,
-    ExClipSequence,
-    ExDefault,
-    ExFinalCutPro,
-    ExJson,
-    Exports,
-    ExPremiere,
-    ExShotCut,
-    ExTimeline,
-)
-from auto_editor.objs.util import Attr
-from auto_editor.output import Ensure
-from auto_editor.timeline import Timeline, make_timeline
+from auto_editor.make_layers import make_timeline
+from auto_editor.objs.util import Attr, Attrs, ParserError, parse_dataclass
+from auto_editor.output import Ensure, mux_quality_media
+from auto_editor.render.audio import make_new_audio
+from auto_editor.render.subtitle import make_new_subtitles
+from auto_editor.render.video import render_av
+from auto_editor.timeline import timeline_builder, v1, v3
 from auto_editor.utils.bar import Bar
 from auto_editor.utils.chunks import Chunk, Chunks
 from auto_editor.utils.container import Container, container_constructor
@@ -27,39 +20,37 @@ from auto_editor.utils.types import Args
 
 def set_output(
     out: str | None, _export: str | None, src: FileInfo | None, log: Log
-) -> tuple[str, Exports]:
-
-    export = None if _export is None else parse_export(_export, log)
-
+) -> tuple[str, dict[str, Any]]:
     if src is None:
         root, ext = "out", ".mp4"
     else:
-        root, ext = os.path.splitext(src.path if out is None else out)
+        root, ext = os.path.splitext(str(src.path) if out is None else out)
         if ext == "":
-            ext = src.ext
+            ext = src.path.suffix
 
-    if export is None:
+    if _export is None:
         if ext == ".xml":
-            export = ExPremiere()
+            export = {"export": "premiere"}
         elif ext == ".fcpxml":
-            export = ExFinalCutPro()
+            export = {"export": "final-cut-pro"}
         elif ext == ".mlt":
-            export = ExShotCut()
+            export = {"export": "shotcut"}
         elif ext == ".json":
-            export = ExJson()
+            export = {"export": "json"}
         else:
-            export = ExDefault()
+            export = {"export": "default"}
+    else:
+        export = parse_export(_export, log)
 
-    if isinstance(export, ExPremiere):
-        ext = ".xml"
-    if isinstance(export, ExFinalCutPro):
-        ext = ".fcpxml"
-    if isinstance(export, ExShotCut):
-        ext = ".mlt"
-    if isinstance(export, ExJson):
-        ext = ".json"
-    if isinstance(export, ExAudio):
-        ext = ".wav"
+    ext_map = {
+        "premiere": ".xml",
+        "final-cut-pro": ".fcpxml",
+        "shotcut": ".mlt",
+        "json": ".json",
+        "audio": ".wav",
+    }
+    if export["export"] in ext_map:
+        ext = ext_map[export["export"]]
 
     if out is None:
         return f"{root}_ALTERED{ext}", export
@@ -136,7 +127,6 @@ def set_audio_codec(
 def make_sources(
     paths: list[str], ffmpeg: FFmpeg, log: Log
 ) -> tuple[dict[str, FileInfo], list[int]]:
-
     used_paths: dict[str, int] = {}
     sources: dict[str, FileInfo] = {}
     inputs: list[int] = []
@@ -153,29 +143,31 @@ def make_sources(
     return sources, inputs
 
 
-def parse_export(export: str, log: Log) -> Exports:
-    from auto_editor.objs.tl import timeline_builder
-    from auto_editor.objs.util import parse_dataclass
-
+def parse_export(export: str, log: Log) -> dict[str, Any]:
     exploded = export.split(":", maxsplit=1)
     if len(exploded) == 1:
-        name, attrs = exploded[0], ""
+        name, text = exploded[0], ""
     else:
-        name, attrs = exploded
+        name, text = exploded
 
-    parsing: dict[str, tuple[Any, list[Attr]]] = {
-        "default": (ExDefault, []),
-        "premiere": (ExPremiere, []),
-        "final-cut-pro": (ExFinalCutPro, []),
-        "shotcut": (ExShotCut, []),
-        "json": (ExJson, timeline_builder),
-        "timeline": (ExTimeline, timeline_builder),
-        "audio": (ExAudio, []),
-        "clip-sequence": (ExClipSequence, []),
+    parsing: dict[str, Attrs] = {
+        "default": Attrs("default"),
+        "premiere": Attrs("premiere", Attr("name", str, None)),
+        "final-cut-pro": Attrs("final-cut-pro", Attr("name", str, None)),
+        "shotcut": Attrs("shotcut"),
+        "json": timeline_builder,
+        "timeline": timeline_builder,
+        "audio": Attrs("audio"),
+        "clip-sequence": Attrs("clip-sequence"),
     }
 
     if name in parsing:
-        return parse_dataclass(attrs, parsing[name], log)
+        try:
+            _tmp = parse_dataclass(text, parsing[name])
+            _tmp["export"] = name
+            return _tmp
+        except ParserError as e:
+            log.error(e)
 
     log.error(f"'{name}': Export must be [{', '.join([s for s in parsing.keys()])}]")
 
@@ -183,32 +175,31 @@ def parse_export(export: str, log: Log) -> Exports:
 def edit_media(
     paths: list[str], ffmpeg: FFmpeg, args: Args, temp: str, log: Log
 ) -> None:
-
     timer = Timer(args.quiet)
     bar = Bar(args.progress)
-    timeline = None
+    tl = None
 
     if paths:
-        path_ext = os.path.splitext(paths[0])[1]
+        path_ext = os.path.splitext(paths[0])[1].lower()
         if path_ext == ".xml":
             from auto_editor.formats.premiere import premiere_read_xml
 
-            timeline = premiere_read_xml(paths[0], ffmpeg, log)
-            src: FileInfo | None = next(iter(timeline.sources.items()))[1]
-            sources = timeline.sources
+            tl = premiere_read_xml(paths[0], ffmpeg, log)
+            src: FileInfo | None = next(iter(tl.sources.items()))[1]
+            sources = tl.sources
 
         elif path_ext == ".mlt":
             from auto_editor.formats.shotcut import shotcut_read_mlt
 
-            timeline = shotcut_read_mlt(paths[0], ffmpeg, log)
-            src = next(iter(timeline.sources.items()))[1]
-            sources = timeline.sources
+            tl = shotcut_read_mlt(paths[0], ffmpeg, log)
+            src = next(iter(tl.sources.items()))[1]
+            sources = tl.sources
 
         elif path_ext == ".json":
             from auto_editor.formats.json import read_json
 
-            timeline = read_json(paths[0], ffmpeg, log)
-            sources = timeline.sources
+            tl = read_json(paths[0], ffmpeg, log)
+            sources = tl.sources
             src = sources["0"]
         else:
             sources, inputs = make_sources(paths, ffmpeg, log)
@@ -217,8 +208,9 @@ def edit_media(
     del paths
 
     output, export = set_output(args.output_file, args.export, src, log)
+    assert "export" in export
 
-    if isinstance(export, ExTimeline):
+    if export["export"] == "timeline":
         log.quiet = True
         timer.quiet = True
 
@@ -233,69 +225,69 @@ def edit_media(
             os.remove(output)
 
     if args.sample_rate is None:
-        if timeline is None:
+        if tl is None:
             samplerate = 48000 if src is None else src.get_samplerate()
         else:
-            samplerate = timeline.samplerate
+            samplerate = tl.sr
     else:
         samplerate = args.sample_rate
 
     ensure = Ensure(ffmpeg, samplerate, temp, log)
 
-    if timeline is None:
+    if tl is None:
         # Extract subtitles in their native format.
         if src is not None and len(src.subtitles) > 0:
-            cmd = ["-i", src.path, "-hide_banner"]
+            cmd = ["-i", f"{src.path}", "-hide_banner"]
             for s, sub in enumerate(src.subtitles):
                 cmd.extend(["-map", f"0:s:{s}"])
             for s, sub in enumerate(src.subtitles):
                 cmd.extend([os.path.join(temp, f"{s}s.{sub.ext}")])
             ffmpeg.run(cmd)
 
-        timeline = make_timeline(
+        tl = make_timeline(
             sources, inputs, ffmpeg, ensure, args, samplerate, bar, temp, log
         )
 
-    if isinstance(export, ExTimeline):
+    if export["export"] == "timeline":
         from auto_editor.formats.json import make_json_timeline
 
-        make_json_timeline(export, 0, timeline, log)
+        make_json_timeline(export["api"], 0, tl, log)
         return
 
     if args.preview:
         from auto_editor.preview import preview
 
-        preview(ensure, timeline, temp, log)
+        preview(ensure, tl, temp, log)
         return
 
-    if isinstance(export, ExJson):
+    if export["export"] == "json":
         from auto_editor.formats.json import make_json_timeline
 
-        make_json_timeline(export, output, timeline, log)
+        make_json_timeline(export["api"], output, tl, log)
         return
 
-    if isinstance(export, ExPremiere):
+    if export["export"] == "premiere":
         from auto_editor.formats.premiere import premiere_write_xml
 
-        premiere_write_xml(ensure, output, timeline)
+        premiere_write_xml(export["name"], ensure, output, tl)
         return
 
-    if isinstance(export, ExFinalCutPro):
+    if export["export"] == "final-cut-pro":
         from auto_editor.formats.final_cut_pro import fcp_xml
 
-        fcp_xml(output, timeline)
+        fcp_xml(export["name"], output, tl)
         return
 
-    if isinstance(export, ExShotCut):
+    if export["export"] == "shotcut":
         from auto_editor.formats.shotcut import shotcut_write_mlt
 
-        shotcut_write_mlt(output, timeline)
+        shotcut_write_mlt(output, tl)
         return
 
     out_ext = os.path.splitext(output)[1].replace(".", "")
 
     # Check if export options make sense.
-    ctr = container_constructor(out_ext)
+    ctr = container_constructor(out_ext.lower())
 
     if ctr.samplerate is not None and args.sample_rate not in ctr.samplerate:
         log.error(f"'{out_ext}' container only supports samplerates: {ctr.samplerate}")
@@ -306,10 +298,7 @@ def edit_media(
     if args.keep_tracks_separate and ctr.max_audios == 1:
         log.warning(f"'{out_ext}' container doesn't support multiple audio tracks.")
 
-    def make_media(timeline: Timeline, output: str) -> None:
-        from auto_editor.output import mux_quality_media
-        from auto_editor.render.video import render_av
-
+    def make_media(tl: v3, output: str) -> None:
         assert src is not None
 
         visual_output = []
@@ -318,27 +307,21 @@ def edit_media(
         apply_later = False
 
         if ctr.allow_subtitle:
-            from auto_editor.render.subtitle import make_new_subtitles
-
-            sub_output = make_new_subtitles(timeline, ffmpeg, temp, log)
+            sub_output = make_new_subtitles(tl, ffmpeg, temp, log)
 
         if ctr.allow_audio:
-            from auto_editor.render.audio import make_new_audio
-
-            audio_output = make_new_audio(timeline, ensure, ffmpeg, bar, temp, log)
+            audio_output = make_new_audio(tl, ensure, ffmpeg, bar, temp, log)
 
         if ctr.allow_video:
-            if len(timeline.v) > 0:
-                out_path, apply_later = render_av(
-                    ffmpeg, timeline, args, bar, ctr, temp, log
-                )
+            if tl.v:
+                out_path, apply_later = render_av(ffmpeg, tl, args, bar, ctr, temp, log)
                 visual_output.append((True, out_path))
 
             for v, vid in enumerate(src.videos, start=1):
                 if ctr.allow_image and vid.codec in ("png", "mjpeg", "webp"):
                     out_path = os.path.join(temp, f"{v}.{vid.codec}")
                     # fmt: off
-                    ffmpeg.run(["-i", src.path, "-map", "0:v", "-map", "-0:V",
+                    ffmpeg.run(["-i", f"{src.path}", "-map", "0:v", "-map", "-0:V",
                         "-c", "copy", out_path])
                     # fmt: on
                     visual_output.append((False, out_path))
@@ -352,18 +335,19 @@ def edit_media(
             apply_later,
             ctr,
             output,
-            timeline.timebase,
+            tl.tb,
             args,
             src,
             temp,
             log,
         )
 
-    if isinstance(export, ExClipSequence):
-        chunks = timeline.chunks
-        if chunks is None:
+    if export["export"] == "clip-sequence":
+        if tl.v1 is None:
             log.error("Timeline to complex to use clip-sequence export")
 
+        sources = {"0": tl.v1.source}
+
         from auto_editor.make_layers import clipify, make_av
         from auto_editor.utils.func import append_filename
 
@@ -372,34 +356,34 @@ def edit_media(
             end = [] if chunk[1] == total else [(chunk[1], total, 99999.0)]
             return start + [chunk] + end
 
-        total_frames = chunks[-1][1] - 1
+        total_frames = tl.v1.chunks[-1][1] - 1
         clip_num = 0
-        for chunk in chunks:
+        for chunk in tl.v1.chunks:
             if chunk[2] == 99999:
                 continue
 
-            _c = pad_chunk(chunk, total_frames)
+            padded_chunks = pad_chunk(chunk, total_frames)
 
-            vspace, aspace = make_av([clipify(_c, "0")], timeline.sources, [0])
-            my_timeline = Timeline(
-                timeline.sources,
-                timeline.timebase,
-                timeline.samplerate,
-                timeline.res,
+            vspace, aspace = make_av([clipify(padded_chunks, "0")], sources, [0])
+            my_timeline = v3(
+                sources,
+                tl.tb,
+                tl.sr,
+                tl.res,
                 "#000",
                 vspace,
                 aspace,
-                _c,
+                v1(tl.v1.source, padded_chunks),
             )
 
             make_media(my_timeline, append_filename(output, f"-{clip_num}"))
             clip_num += 1
     else:
-        make_media(timeline, output)
+        make_media(tl, output)
 
     timer.stop()
 
-    if not args.no_open and isinstance(export, (ExDefault, ExAudio, ExClipSequence)):
+    if not args.no_open and export["export"] in ("default", "audio", "clip-sequence"):
         if args.player is None:
             from auto_editor.utils.func import open_with_system_default
 
