@@ -6,6 +6,7 @@ import subprocess
 import sys
 from dataclasses import dataclass
 from fractions import Fraction
+from pathlib import Path
 from platform import system
 from re import search
 from subprocess import PIPE, Popen
@@ -19,12 +20,13 @@ SUB_EXTS = {"mov_text": "srt", "ass": "ass", "webvtt": "vtt"}
 
 
 class FFmpeg:
-    __slots__ = ("debug", "path", "version")
+    __slots__ = ("debug", "show_cmd", "path", "version")
 
     def __init__(
         self,
         ff_location: str | None = None,
         my_ffmpeg: bool = False,
+        show_cmd: bool = False,
         debug: bool = False,
     ):
         def _set_ff_path(ff_location: str | None, my_ffmpeg: bool) -> str:
@@ -41,6 +43,7 @@ class FFmpeg:
                 return "ffmpeg"
 
         self.debug = debug
+        self.show_cmd = show_cmd
         self.path = _set_ff_path(ff_location, my_ffmpeg)
         try:
             _version = get_stdout([self.path, "-version"]).split("\n")[0]
@@ -64,11 +67,11 @@ class FFmpeg:
             sys.stderr.write(f"FFmpeg: {message}\n")
 
     def print_cmd(self, cmd: list[str]) -> None:
-        if self.debug:
-            sys.stderr.write(f"FFmpeg run: {' '.join(cmd)}\n")
+        if self.show_cmd:
+            sys.stderr.write(f"{' '.join(cmd)}\n\n")
 
     def run(self, cmd: list[str]) -> None:
-        cmd = [self.path, "-y", "-hide_banner"] + cmd
+        cmd = [self.path, "-hide_banner", "-y"] + cmd
         if not self.debug:
             cmd.extend(["-nostats", "-loglevel", "error"])
         self.print_cmd(cmd)
@@ -81,7 +84,6 @@ class FFmpeg:
         show_out: bool = False,
         path: str | None = None,
     ) -> None:
-
         process = self.Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
         _, stderr = process.communicate()
 
@@ -152,6 +154,7 @@ class VideoStream:
 class AudioStream:
     codec: str
     samplerate: int
+    channels: int
     duration: str | None
     bitrate: str | None
     lang: str | None
@@ -167,11 +170,6 @@ class SubtitleStream:
 class FileInfo:
     __slots__ = (
         "path",
-        "abspath",
-        "basename",
-        "dirname",
-        "name",
-        "ext",
         "modified",
         "bitrate",
         "duration",
@@ -183,28 +181,23 @@ class FileInfo:
     )
 
     def get_res(self) -> tuple[int, int]:
-        if len(self.videos) > 0:
+        if self.videos:
             return self.videos[0].width, self.videos[0].height
         return 1920, 1080
 
     def get_fps(self) -> Fraction:
-        if len(self.videos) > 0:
+        if self.videos:
             return self.videos[0].fps
         return Fraction(30)
 
     def get_samplerate(self) -> int:
-        if len(self.audios) > 0:
+        if self.audios:
             return self.audios[0].samplerate
         return 48000
 
     def __init__(self, path: str, ffmpeg: FFmpeg, log: Log, label: str = ""):
         self.label = label
-        self.path = path
-        self.abspath = os.path.abspath(path)
-        self.basename = os.path.basename(path)
-        self.dirname = os.path.dirname(os.path.abspath(path))
-        self.name, self.ext = os.path.splitext(path)
-
+        self.path = Path(path)
         self.videos: list[VideoStream] = []
         self.audios: list[AudioStream] = []
         self.subtitles: list[SubtitleStream] = []
@@ -315,7 +308,7 @@ class FileInfo:
                         log.error(
                             f"Could not convert time_base '{time_base_str}' to Fraction."
                         )
-                    time_base = Fraction(0, 1)
+                    time_base = Fraction(0)
 
                 self.videos.append(
                     VideoStream(
@@ -337,8 +330,13 @@ class FileInfo:
                 )
             if codec_type == "audio":
                 sr = int(stream["sample_rate"])
+
+                if "channels" not in stream:
+                    log.error("audio stream has no 'channels' data")
+                c = int(stream["channels"])
+
                 adur = get_attr("duration", stream, default=None)
-                self.audios.append(AudioStream(codec, sr, adur, br, lang))
+                self.audios.append(AudioStream(codec, sr, c, adur, br, lang))
             if codec_type == "subtitle":
                 ext = SUB_EXTS.get(codec, "vtt")
                 self.subtitles.append(SubtitleStream(codec, ext, lang))
