@@ -1,11 +1,9 @@
 from __future__ import annotations
 
 from fractions import Fraction
-from pathlib import Path, PureWindowsPath
-from platform import system
 
 from auto_editor.ffwrapper import FileInfo
-from auto_editor.timeline import Timeline
+from auto_editor.timeline import v3
 
 from .utils import indent
 
@@ -66,27 +64,22 @@ def fraction(_a: float, tb: Fraction) -> str:
     return f"{num}/{dem}s"
 
 
-def fcp_xml(output: str, timeline: Timeline) -> None:
-    src = timeline.sources["0"]
-    tb = timeline.timebase
-    chunks = timeline.chunks
-
-    if chunks is None:
-        raise ValueError("Timeline too complex")
+def fcp_xml(_group_name: str | None, output: str, tl: v3) -> None:
+    assert tl.v1 is not None
+    src = tl.v1.source
+    chunks = tl.v1.chunks
+    tb = tl.tb
 
     total_dur = chunks[-1][1]
+    pathurl = src.path.resolve().as_uri()
+    width, height = tl.res
+    name = src.path.stem
 
-    if system() == "Windows":
-        pathurl = "file://localhost/" + PureWindowsPath(src.abspath).as_posix()
+    if _group_name is None:
+        is_audio = not src.videos and src.audios
+        group_name = f"Auto-Editor {'Audio' if is_audio else 'Video'} Group"
     else:
-        pathurl = Path(src.abspath).as_uri()
-
-    width, height = timeline.res
-    frame_duration = fraction(1, tb)
-
-    audio_file = len(src.videos) == 0 and len(src.audios) > 0
-    group_name = "Auto-Editor {} Group".format("Audio" if audio_file else "Video")
-    name = src.basename
+        group_name = _group_name
 
     colorspace = get_colorspace(src)
 
@@ -97,7 +90,7 @@ def fcp_xml(output: str, timeline: Timeline) -> None:
         outfile.write("\t<resources>\n")
         outfile.write(
             f'\t\t<format id="r1" name="FFVideoFormat{height}p{float(tb)}" '
-            f'frameDuration="{frame_duration}" '
+            f'frameDuration="{fraction(1, tb)}" '
             f'width="{width}" height="{height}" '
             f'colorSpace="{colorspace}"/>\n'
         )
