@@ -7,15 +7,112 @@ from fractions import Fraction
 from typing import Any
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
-from auto_editor.objs.export import ExJson, ExTimeline
-from auto_editor.objs.util import parse_dataclass
-from auto_editor.timeline import Timeline, audio_objects, visual_objects
+from auto_editor.objs.util import Attr, Attrs, ParserError, Required, parse_dataclass
+from auto_editor.timeline import (
+    TlAudio,
+    TlEllipse,
+    TlImage,
+    TlRect,
+    TlText,
+    TlVideo,
+    Visual,
+    v3,
+)
 from auto_editor.utils.log import Log
+from auto_editor.utils.types import (
+    align,
+    anchor,
+    color,
+    natural,
+    number,
+    src,
+    threshold,
+)
 
 """
 Make a pre-edited file reference that can be inputted back into auto-editor.
 """
 
+video_builder = Attrs(
+    "video",
+    Attr("start", natural, Required),
+    Attr("dur", natural, Required),
+    Attr("src", src, Required),
+    Attr("offset", natural, 0),
+    Attr("speed", number, 1),
+    Attr("stream", natural, 0),
+)
+audio_builder = Attrs(
+    "audio",
+    Attr("start", natural, Required),
+    Attr("dur", natural, Required),
+    Attr("src", src, Required),
+    Attr("offset", natural, 0),
+    Attr("speed", number, 1),
+    Attr("volume", threshold, 1),
+    Attr("stream", natural, 0),
+)
+text_builder = Attrs(
+    "text",
+    Attr("start", natural, Required),
+    Attr("dur", natural, Required),
+    Attr("content", str, Required),
+    Attr("x", int, "50%"),
+    Attr("y", int, "50%"),
+    Attr("font", str, "Arial"),
+    Attr("size", natural, 55),
+    Attr("align", align, "left"),
+    Attr("opacity", threshold, 1),
+    Attr("anchor", anchor, "ce"),
+    Attr("rotate", number, 0),
+    Attr("fill", str, "#FFF"),
+    Attr("stroke", natural, 0),
+    Attr("strokecolor", color, "#000"),
+)
+
+img_builder = Attrs(
+    "image",
+    Attr("start", natural, Required),
+    Attr("dur", natural, Required),
+    Attr("src", src, Required),
+    Attr("x", int, "50%"),
+    Attr("y", int, "50%"),
+    Attr("opacity", threshold, 1),
+    Attr("anchor", anchor, "ce"),
+    Attr("rotate", number, 0),
+    Attr("stroke", natural, 0),
+    Attr("strokecolor", color, "#000"),
+)
+
+rect_builder = Attrs(
+    "rect",
+    Attr("start", natural, Required),
+    Attr("dur", natural, Required),
+    Attr("x", int, Required),
+    Attr("y", int, Required),
+    Attr("width", int, Required),
+    Attr("height", int, Required),
+    Attr("opacity", threshold, 1),
+    Attr("anchor", anchor, "ce"),
+    Attr("rotate", number, 0),
+    Attr("fill", color, "#c4c4c4"),
+    Attr("stroke", natural, 0),
+    Attr("strokecolor", color, "#000"),
+)
+ellipse_builder = rect_builder
+
+visual_objects = {
+    "rectangle": (TlRect, rect_builder),
+    "ellipse": (TlEllipse, ellipse_builder),
+    "text": (TlText, text_builder),
+    "image": (TlImage, img_builder),
+    "video": (TlVideo, video_builder),
+}
+
+audio_objects = {
+    "audio": (TlAudio, audio_builder),
+}
+
 
 def check_attrs(data: object, log: Log, *attrs: str) -> None:
     if not isinstance(data, dict):
@@ -34,6 +131,9 @@ class Version:
     __slots__ = ("major", "minor", "micro")
 
     def __init__(self, val: str, log: Log) -> None:
+        if val.startswith("unstable:"):
+            val = val[9:]
+
         ver_str = val.split(".")
         if len(ver_str) > 3:
             log.error("Version string: Too many separators!")
@@ -54,14 +154,14 @@ class Version:
         return f"{self.major}.{self.minor}.{self.micro}"
 
 
-def read_json(path: str, ffmpeg: FFmpeg, log: Log) -> Timeline:
+def read_json(path: str, ffmpeg: FFmpeg, log: Log) -> v3:
     with open(path) as f:
         data = json.load(f)
 
     check_attrs(data, log, "version")
     version = Version(data["version"], log)
 
-    if version == (2, 0) or version == (0, 2):
+    if version == (3, 0):
         check_attrs(data, log, "timeline")
         tl = data["timeline"]
         check_attrs(
@@ -98,16 +198,21 @@ def read_json(path: str, ffmpeg: FFmpeg, log: Log) -> Timeline:
 
         for vlayers in tl["v"]:
             if vlayers:
-                v_out = []
+                v_out: list[Visual] = []
                 for vdict in vlayers:
                     if "name" not in vdict:
                         log.error("Invalid video object: name not specified")
                     if vdict["name"] not in visual_objects:
                         log.error(f"Unknown video object: {vdict['name']}")
-                    my_obj = visual_objects[vdict["name"]]
-                    attr_str = dict_to_args(vdict)
-                    vobj = parse_dataclass(attr_str, my_obj, log, None, True)
-                    v_out.append(vobj)
+                    my_vobj, my_build = visual_objects[vdict["name"]]
+
+                    text = dict_to_args(vdict)
+                    try:
+                        my_dict = parse_dataclass(text, my_build, coerce_default=True)
+                        v_out.append(my_vobj(**my_dict))
+                    except ParserError as e:
+                        log.error(e)
+
                 v.append(v_out)
 
         for alayers in tl["a"]:
@@ -118,27 +223,29 @@ def read_json(path: str, ffmpeg: FFmpeg, log: Log) -> Timeline:
                         log.error("Invalid audio object: name not specified")
                     if adict["name"] not in audio_objects:
                         log.error(f"Unknown audio object: {adict['name']}")
-                    my_obj = audio_objects[adict["name"]]
-                    attr_str = dict_to_args(adict)
-                    aobj = parse_dataclass(attr_str, my_obj, log, None, True)
-                    a_out.append(aobj)
+                    my_aobj, my_build = audio_objects[adict["name"]]
+
+                    text = dict_to_args(adict)
+                    try:
+                        my_dict = parse_dataclass(text, my_build, coerce_default=True)
+                        a_out.append(my_aobj(**my_dict))
+                    except ParserError as e:
+                        log.error(e)
+
                 a.append(a_out)
 
-        return Timeline(sources, tb, sr, res, bg, v, a)
+        return v3(sources, tb, sr, res, bg, v, a, None)
 
     log.error(f"Importing version {version} timelines is not supported.")
 
 
-def make_json_timeline(
-    obj: ExJson | ExTimeline,
-    out: str | int,
-    tl: Timeline,
-    log: Log,
-) -> None:
-
-    if (version := Version(obj.api, log)) != (2, 0) and version != (0, 2):
+def make_json_timeline(ver: str, out: str | int, tl: object, log: Log) -> None:
+    if (version := Version(ver, log)) != (3, 0):
         log.error(f"Version {version} is not supported!")
 
+    if not isinstance(tl, v3):
+        raise ValueError("Wrong tl object!")
+
     if isinstance(out, str):
         if not out.endswith(".json"):
             log.error("Output extension must be .json")
