@@ -4,19 +4,19 @@ import os.path
 import xml.etree.ElementTree as ET
 from fractions import Fraction
 from math import ceil
-from os.path import abspath
-from pathlib import Path
 from shutil import move
+from typing import TYPE_CHECKING
 from xml.etree.ElementTree import Element
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
-from auto_editor.objs.tl import ASpace, TlAudio, TlVideo, VSpace
-from auto_editor.output import Ensure
-from auto_editor.timeline import Timeline
-from auto_editor.utils.log import Log
+from auto_editor.timeline import ASpace, TlAudio, TlVideo, VSpace, v3
 
 from .utils import Validator, safe_mkdir, show
 
+if TYPE_CHECKING:
+    from auto_editor.output import Ensure
+    from auto_editor.utils.log import Log
+
 """
 Premiere Pro uses the Final Cut Pro 7 XML Interchange Format
 
@@ -38,7 +38,8 @@ def uri_to_path(uri: str) -> str:
     from urllib.request import url2pathname
 
     parsed = urlparse(uri)
-    host = "{0}{0}{mnt}{0}".format(os.path.sep, mnt=parsed.netloc)
+    s = os.path.sep
+    host = f"{s}{s}{parsed.netloc}{s}"
     return os.path.normpath(os.path.join(host, url2pathname(parsed.path)))
 
     # /Users/wyattblue/projects/auto-editor/example.mp4
@@ -103,7 +104,7 @@ def speedup(speed: float) -> Element:
     return fil
 
 
-def premiere_read_xml(path: str, ffmpeg: FFmpeg, log: Log) -> Timeline:
+def premiere_read_xml(path: str, ffmpeg: FFmpeg, log: Log) -> v3:
     def xml_bool(val: str) -> bool:
         if val == "TRUE":
             return True
@@ -244,48 +245,42 @@ def premiere_read_xml(path: str, ffmpeg: FFmpeg, log: Log) -> Timeline:
                     TlAudio(start, dur, file_id, offset, speed=1, volume=1, stream=0)
                 )
 
-    timeline = Timeline(sources, tb, sr, res, "#000", vobjs, aobjs, None)
-    return timeline
+    return v3(sources, tb, sr, res, "#000", vobjs, aobjs, None)
 
 
-def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
+def premiere_write_xml(_name: str | None, ensure: Ensure, output: str, tl: v3) -> None:
+    assert tl.v1 is not None
 
-    if timeline.chunks is None:
-        raise ValueError("Timeline too complex")
+    clips = list(filter(lambda c: c[2] != 99999, tl.v1.chunks))
+    duration = tl.v1.chunks[-1][1]
 
-    clips = []
-    duration = timeline.chunks[-1][1]
-    for chunk in timeline.chunks:
-        if chunk[2] != 99999:
-            clips.append(chunk)
-
-    samplerate = timeline.samplerate
-    src = timeline.sources["0"]
+    src = tl.v1.source
+    width, height = tl.res
 
     audio_file = len(src.videos) == 0 and len(src.audios) == 1
-    timebase, ntsc = set_tb_ntsc(timeline.timebase)
+    timebase, ntsc = set_tb_ntsc(tl.tb)
 
-    pathurls = [Path(src.abspath).as_uri()]
+    pathurls = [str(src.path.resolve())]
 
     tracks = len(src.audios)
 
     if tracks > 1:
-        name_without_extension = src.basename[: src.basename.rfind(".")]
-
-        fold = safe_mkdir(os.path.join(src.dirname, f"{name_without_extension}_tracks"))
+        fold = src.path.parent / f"{src.path.stem}_tracks"
+        safe_mkdir(fold)
 
         for i in range(1, tracks):
-            newtrack = os.path.join(fold, f"{i}.wav")
-            move(ensure.audio(src.path, "0", i), newtrack)
-            pathurls.append(Path(abspath(newtrack)).as_uri())
+            newtrack = fold / f"{i}.wav"
+            move(ensure.audio(f"{src.path.resolve()}", "0", i), newtrack)
+            pathurls.append(str(newtrack.resolve()))
 
-    width, height = timeline.res
-
-    group_name = f"Auto-Editor {'Audio' if audio_file else 'Video'} Group"
+    if _name is None:
+        name = f"Auto-Editor {'Audio' if audio_file else 'Video'} Group"
+    else:
+        name = _name
 
     xmeml = ET.Element("xmeml", version="4")
     sequence = ET.SubElement(xmeml, "sequence")
-    ET.SubElement(sequence, "name").text = group_name
+    ET.SubElement(sequence, "name").text = name
     ET.SubElement(sequence, "duration").text = str(duration)
     rate = ET.SubElement(sequence, "rate")
     ET.SubElement(rate, "timebase").text = str(timebase)
@@ -309,7 +304,6 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
 
         total = 0.0
         for j, clip in enumerate(clips):
-
             clip_duration = (clip[1] - clip[0]) / clip[2]
 
             _start = int(total)
@@ -321,7 +315,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
 
             clipitem = ET.SubElement(track, "clipitem", id=f"clipitem-{j+1}")
             ET.SubElement(clipitem, "masterclipid").text = "masterclip-2"
-            ET.SubElement(clipitem, "name").text = src.basename
+            ET.SubElement(clipitem, "name").text = src.path.stem
             ET.SubElement(clipitem, "start").text = str(_start)
             ET.SubElement(clipitem, "end").text = str(_end)
             ET.SubElement(clipitem, "in").text = str(_in)
@@ -330,7 +324,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
             filedef = ET.SubElement(clipitem, "file", id="file-1")
 
             if j == 0:
-                ET.SubElement(filedef, "name").text = src.basename
+                ET.SubElement(filedef, "name").text = src.path.stem
                 ET.SubElement(filedef, "pathurl").text = pathurls[0]
 
                 rate = ET.SubElement(filedef, "rate")
@@ -354,7 +348,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
                 audiodef = ET.SubElement(mediadef, "audio")
                 aschar = ET.SubElement(audiodef, "samplecharacteristics")
                 ET.SubElement(aschar, "depth").text = DEPTH
-                ET.SubElement(aschar, "samplerate").text = str(samplerate)
+                ET.SubElement(aschar, "samplerate").text = str(tl.sr)
                 ET.SubElement(audiodef, "channelcount").text = "2"
 
             if clip[2] != 1:
@@ -377,7 +371,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
     aformat = ET.SubElement(audio, "format")
     aschar = ET.SubElement(aformat, "samplecharacteristics")
     ET.SubElement(aschar, "depth").text = DEPTH
-    ET.SubElement(aschar, "samplerate").text = str(samplerate)
+    ET.SubElement(aschar, "samplerate").text = str(tl.sr)
 
     for t in range(tracks):
         track = ET.Element(
@@ -386,7 +380,6 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
 
         total = 0
         for j, clip in enumerate(clips):
-
             clip_duration = (clip[1] - clip[0]) / clip[2]
 
             _start = int(total)
@@ -410,7 +403,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
                 premiereChannelType="stereo",
             )
             ET.SubElement(clipitem, "masterclipid").text = f"masterclip-{master_id}"
-            ET.SubElement(clipitem, "name").text = src.basename
+            ET.SubElement(clipitem, "name").text = src.path.stem
             ET.SubElement(clipitem, "start").text = str(_start)
             ET.SubElement(clipitem, "end").text = str(_end)
             ET.SubElement(clipitem, "in").text = str(_in)
@@ -418,7 +411,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
 
             filedef = ET.SubElement(clipitem, "file", id=f"file-{t+1}")
             if j == 0 and (audio_file or t > 0):
-                ET.SubElement(filedef, "name").text = src.basename
+                ET.SubElement(filedef, "name").text = src.path.stem
                 ET.SubElement(filedef, "pathurl").text = pathurls[t]
 
                 rate = ET.SubElement(filedef, "rate")
@@ -429,7 +422,7 @@ def premiere_write_xml(ensure: Ensure, output: str, timeline: Timeline) -> None:
                 media_audio = ET.SubElement(media, "audio")
                 maschar = ET.SubElement(media_audio, "samplecharacteristics")
                 ET.SubElement(maschar, "depth").text = DEPTH
-                ET.SubElement(maschar, "samplerate").text = str(samplerate)
+                ET.SubElement(maschar, "samplerate").text = str(tl.sr)
                 ET.SubElement(media_audio, "channelcount").text = "2"
 
             sourcetrack = ET.SubElement(clipitem, "sourcetrack")
