@@ -21,10 +21,10 @@ def desc_options(parser: ArgumentParser) -> ArgumentParser:
     return parser
 
 
-def main(sys_args: list[str]) -> None:
+def main(sys_args: list[str] = sys.argv[1:]) -> None:
     args = desc_options(ArgumentParser("desc")).parse_args(DescArgs, sys_args)
     for path in args.input:
-        src = FileInfo(path, FFmpeg(args.ffmpeg_location, debug=False), Log())
+        src = FileInfo(path, FFmpeg(args.ffmpeg_location), Log())
         if src.description is not None:
             sys.stdout.write(f"\n{src.description}\n\n")
         else:
@@ -32,4 +32,4 @@ def main(sys_args: list[str]) -> None:
 
 
 if __name__ == "__main__":
-    main(sys.argv[1:])
+    main()
