@@ -7,6 +7,7 @@ from dataclasses import dataclass, field
 from typing import Any, Literal, TypedDict
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
+from auto_editor.timeline import v3
 from auto_editor.utils.func import aspect_ratio
 from auto_editor.utils.log import Log
 from auto_editor.vanparse import ArgumentParser
@@ -60,6 +61,7 @@ class VideoJson(TypedDict):
 class AudioJson(TypedDict):
     codec: str
     samplerate: int
+    channels: int
     duration: str | None
     bitrate: str | None
     lang: str | None
@@ -82,14 +84,14 @@ class MediaJson(TypedDict, total=False):
     subtitle: list[SubtitleJson]
     container: ContainerJson
     type: Literal["media", "timeline", "unknown"]
-    version: Literal["v1", "v2"]
+    version: Literal["v1", "v2", "v3"]
     clips: int
 
 
-def main(sys_args: list[str]) -> None:
+def main(sys_args: list[str] = sys.argv[1:]) -> None:
     args = info_options(ArgumentParser("info")).parse_args(InfoArgs, sys_args)
 
-    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
+    ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg)
     log = Log(quiet=not args.json)
 
     file_info: dict[str, MediaJson] = {}
@@ -104,7 +106,7 @@ def main(sys_args: list[str]) -> None:
 
             tl = read_json(file, ffmpeg, log)
             file_info[file] = {"type": "timeline"}
-            file_info[file]["version"] = "v2" if tl.chunks is None else "v1"
+            file_info[file]["version"] = "v3" if isinstance(tl, v3) else "v1"
 
             clip_lens = [clip.dur / clip.speed for clip in tl.a[0]]
             file_info[file]["clips"] = len(clip_lens)
@@ -158,6 +160,7 @@ def main(sys_args: list[str]) -> None:
             aud: AudioJson = {
                 "codec": a.codec,
                 "samplerate": a.samplerate,
+                "channels": a.channels,
                 "duration": a.duration,
                 "bitrate": a.bitrate,
                 "lang": a.lang,
@@ -228,4 +231,4 @@ def main(sys_args: list[str]) -> None:
 
 
 if __name__ == "__main__":
-    main(sys.argv[1:])
+    main()
