@@ -1,5 +1,3 @@
-# type: ignore
-
 from __future__ import annotations
 
 import sys
@@ -7,17 +5,11 @@ from dataclasses import dataclass, field
 from fractions import Fraction
 
 import auto_editor
+from auto_editor.analyze import FileSetup
 from auto_editor.ffwrapper import FFmpeg, FileInfo
-from auto_editor.interpreter import (
-    Cons,
-    FileSetup,
-    Interpreter,
-    Lexer,
-    MyError,
-    Parser,
-    Symbol,
-    print_val,
-)
+from auto_editor.interpreter import ClosingError, Lexer, Parser, env, interpret
+from auto_editor.lib.data_structs import print_str
+from auto_editor.lib.err import MyError
 from auto_editor.output import Ensure
 from auto_editor.utils.bar import Bar
 from auto_editor.utils.func import setup_tempdir
@@ -30,6 +22,7 @@ try:
 except ImportError:
     pass
 
+
 @dataclass
 class REPL_Args:
     input: list[str] = field(default_factory=list)
@@ -63,25 +56,10 @@ def repl_options(parser: ArgumentParser) -> ArgumentParser:
     return parser
 
 
-def display_val(val: Any) -> str:
-    if val is None:
-        return ""
-    if isinstance(val, (list, Cons, Symbol)):
-        return f"'{print_val(val)}\n"
-    if isinstance(val, Fraction):
-        return f"{val.numerator}/{val.denominator}\n"
-
-    return f"{print_val(val)}\n"
-
-
 def main(sys_args: list[str] = sys.argv[1:]) -> None:
-    parser = repl_options(ArgumentParser(None))
-    args = parser.parse_args(REPL_Args, sys_args)
+    args = repl_options(ArgumentParser(None)).parse_args(REPL_Args, sys_args)
 
-    if len(args.input) == 0:
-        filesetup = None
-        log = Log(quiet=True)
-    else:
+    if args.input:
         temp = setup_tempdir(args.temp_dir, Log())
         log = Log(quiet=True, temp=temp)
         ffmpeg = FFmpeg(args.ffmpeg_location, args.my_ffmpeg, False)
@@ -94,27 +72,44 @@ def main(sys_args: list[str] = sys.argv[1:]) -> None:
         tb = src.get_fps() if args.timebase is None else args.timebase
         ensure = Ensure(ffmpeg, src.get_samplerate(), temp, log)
         filesetup = FileSetup(src, ensure, strict, tb, Bar("none"), temp, log)
+        env["timebase"] = tb
+        env["@filesetup"] = filesetup
 
     print(f"Auto-Editor {auto_editor.version} ({auto_editor.__version__})")
+    text = None
 
     try:
         while True:
-            text = input("> ")
+            try:
+                if text is None:
+                    text = input("> ")
+                else:
+                    text += " " + input("   ")
+            except KeyboardInterrupt as e:
+                if text is None:
+                    raise e
+                text = None
+                print("")
+                continue
 
             try:
                 lexer = Lexer(text)
                 parser = Parser(lexer)
             except MyError as e:
+                text = None
                 print(f"error: {e}")
                 continue
-
             try:
-                interpreter = Interpreter(parser, filesetup)
-                for result in interpreter.interpret():
-                    sys.stdout.write(display_val(result))
+                for result in interpret(env, parser):
+                    if result is not None:
+                        sys.stdout.write(f"{print_str(result)}\n")
+            except ClosingError:
+                continue  # Allow user to continue adding text
             except (MyError, ZeroDivisionError) as e:
                 print(f"error: {e}")
 
+            text = None
+
     except (KeyboardInterrupt, EOFError):
         print("")
 
