@@ -1,21 +1,21 @@
 # type: ignore
 from __future__ import annotations
 
-import json
 import os
-import platform
 import shutil
 import subprocess
 import sys
 from dataclasses import dataclass, field
 from fractions import Fraction
 from time import perf_counter
-from typing import Callable
+from typing import Any, Callable
 
 import numpy as np
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
-from auto_editor.interpreter import ConsType, Interpreter, Lexer, MyError, Null, Parser
+from auto_editor.interpreter import Lexer, Parser, env, interpret
+from auto_editor.lib.data_structs import Char, Cons, Null, Sym
+from auto_editor.lib.err import MyError
 from auto_editor.utils.log import Log
 from auto_editor.vanparse import ArgumentParser
 
@@ -32,7 +32,7 @@ def test_options(parser):
     parser.add_required(
         "category",
         nargs=1,
-        choices=("unit", "cli", "sub", "api", "all"),
+        choices=("palet", "cli", "sub", "all"),
         metavar="category [options]",
     )
     return parser
@@ -55,10 +55,7 @@ class Checker:
 
 class Runner:
     def __init__(self) -> None:
-        if platform.system() == "Windows":
-            self.program = ["py", "-m", "auto_editor"]
-        else:
-            self.program = ["python3", "-m", "auto_editor"]
+        self.program = [sys.executable, "-m", "auto_editor"]
 
     def main(
         self, inputs: list[str], cmd: list[str], output: str | None = None
@@ -103,7 +100,9 @@ class Runner:
                 if match is not None and match not in stderr:
                     raise Exception(f'Could\'t find "{match}"')
             else:
-                raise Exception(f"Program crashed.\n{stdout}\n{stderr}")
+                raise Exception(
+                    f"Program crashed but should have shown an error.\n{' '.join(cmd)}\n{stdout}\n{stderr}"
+                )
         else:
             raise Exception("Program should not respond with code 0 but did!")
 
@@ -121,7 +120,7 @@ def run_tests(tests: list[Callable], args: TestArgs) -> None:
         clean(os.getcwd())
 
     if args.only != []:
-        tests = filter(lambda t: t.__name__ in args.only, tests)
+        tests = list(filter(lambda t: t.__name__ in args.only, tests))
 
     total_time = 0
 
@@ -169,13 +168,6 @@ def main(sys_args: list[str] | None = None):
 
     ## API Tests ##
 
-    def read_api_0_1():
-        run.check(
-            ["resources/json/0.1-non-zero-start.json"],
-            "Error! First chunk must start with 0",
-        )
-        run.check(["resources/json/0.1-disjoint.json"], "Error! Chunk disjointed at")
-
     def help_tests():
         """check the help option, its short, and help on options and groups."""
         run.raw(["--help"])
@@ -208,9 +200,6 @@ def main(sys_args: list[str] | None = None):
     def subdump():
         run.raw(["subdump", "resources/subtitle.mp4"])
 
-    def grep():
-        run.raw(["grep", "boop", "resources/subtitle.mp4"])
-
     def desc():
         run.raw(["desc", "example.mp4"])
 
@@ -238,7 +227,7 @@ def main(sys_args: list[str] | None = None):
                 "--source",
                 "snd:resources/wav/pcm-f32le.wav",
                 "--add",
-                "audio:0.3sec,end,snd,volume=0.3",
+                'audio:0.3sec,end,"snd",volume=0.3',
             ],
         )
         return run.main(
@@ -247,7 +236,7 @@ def main(sys_args: list[str] | None = None):
                 "--source",
                 "snd:resources/wav/pcm-f32le.wav",
                 "--add",
-                "audio:2,40,snd,3sec",
+                'audio:2,40,"snd",3sec',
             ],
         )
 
@@ -255,29 +244,15 @@ def main(sys_args: list[str] | None = None):
     def high_speed_test():
         return run.main(inputs=["example.mp4"], cmd=["--video-speed", "99998"])
 
-    # Issue #288
-    def expand_chunks():
-        out = run.main(
-            inputs=["example.mp4"],
-            cmd=["--silent-speed", "1"],
-            output="out.json",
-        )
-        with open(out) as file:
-            api = json.load(file)
-        assert len(api["chunks"]) > 4, "Chunks should not combine"
-        return out
-
     # Issue #184
     def units():
         run.main(["example.mp4"], ["--mark_as_loud", "20s,22sec", "25secs,26.5seconds"])
-        run.main(["example.mp4"], ["--edit", "all", "--set-speed", "125%,-30,end"])
-        run.main(["example.mp4"], ["--margin", "3_0"])
+        run.main(["example.mp4"], ["--edit", "all/e", "--set-speed", "125%,-30,end"])
         return run.main(["example.mp4"], ["--edit", "audio:threshold=4%"])
 
     def sr_units():
         run.main(["example.mp4"], ["--sample_rate", "44100 Hz"])
-        run.main(["example.mp4"], ["--sample_rate", "44.1 kHz"])
-        return run.main(["example.mp4"], ["--sample_rate", "44_100"])
+        return run.main(["example.mp4"], ["--sample_rate", "44.1 kHz"])
 
     def video_speed():
         return run.main(["example.mp4"], ["--video-speed", "1.5"])
@@ -288,7 +263,7 @@ def main(sys_args: list[str] | None = None):
         range.
         """
         run.main(["example.mp4"], ["--edit", "none", "--cut_out", "-5secs,end"])
-        return run.main(["example.mp4"], ["--edit", "all", "--add_in", "-5secs,end"])
+        return run.main(["example.mp4"], ["--edit", "all/e", "--add_in", "-5secs,end"])
 
     def cut_out():
         run.main(
@@ -306,7 +281,7 @@ def main(sys_args: list[str] | None = None):
         )
         return run.main(
             ["example.mp4"],
-            ["--edit", "all", "--video_speed", "2", "--add_in", "2secs,10secs"],
+            ["--edit", "all/e", "--video_speed", "2", "--add_in", "2secs,10secs"],
         )
 
     def gif():
@@ -395,7 +370,7 @@ def main(sys_args: list[str] | None = None):
     def obj_makes_video():
         out = run.main(
             ["resources/new-commentary.mp3"],
-            ["--add", "rectangle:0,30,0,0,300,300,fill=blue"],
+            ["--add", 'rectangle:0,30,0,0,300,300,fill="blue"'],
             "out.mp4",
         )
         cn = checker.check(out)
@@ -417,7 +392,7 @@ def main(sys_args: list[str] | None = None):
                 "--mark_as_loud",
                 "start,end",
                 "--add",
-                "rectangle:0,30,0,200,100,300,fill=#43FA56,stroke=10",
+                'rectangle:0,30,0,200,100,300,fill="#43FA56",stroke=10',
             ],
         )
 
@@ -426,9 +401,9 @@ def main(sys_args: list[str] | None = None):
             ["example.mp4"],
             [
                 "--add",
-                "ellipse:0,30,50%,50%,300,300,fill=red",
-                "rectangle:0,30,500,440,400,200,fill=skyblue",
-                "ellipse:0,30,50%,50%,100,100,fill=darkgreen",
+                'ellipse:0,30,50%,50%,300,300,fill="red"',
+                'rectangle:0,30,500,440,400,200,fill="skyblue"',
+                'ellipse:0,30,50%,50%,100,100,fill="darkgreen"',
                 "--edit",
                 "none",
                 "--cut-out",
@@ -441,8 +416,8 @@ def main(sys_args: list[str] | None = None):
             ["example.mp4"],
             [
                 "--add",
-                "ellipse:0,60,50%,50%,300,300,fill=darkgreen",
-                "ellipse:0,30,50%,50%,200,200,fill=green",
+                'ellipse:0,60,50%,50%,300,300,fill="darkgreen"',
+                'ellipse:0,30,50%,50%,200,200,fill="green"',
                 "--edit",
                 "none",
                 "--cut-out",
@@ -454,11 +429,13 @@ def main(sys_args: list[str] | None = None):
 
     def render_text():
         return run.main(
-            ["example.mp4"], ["--add", "text:0,30,This is my text,font=default"]
+            ["example.mp4"], ["--add", 'text:0,30,"This, is my text",font="default"']
         )
 
     def check_font_error():
-        run.check(["example.mp4", "--add", "text:0,30,text,0,0,notafont"], "not found")
+        run.check(
+            ["example.mp4", "--add", 'text:0,30,"text",0,0,"notafont"'], "not found"
+        )
 
     def export():
         results = set()
@@ -478,11 +455,12 @@ def main(sys_args: list[str] | None = None):
             run.main([test_file], ["--edit", "none"])
 
             p_xml = run.main([test_file], ["-exp"])
-            run.main([p_xml], [])
+            results.add(p_xml)
+            results.add(run.main([p_xml], []))
 
-            run.main([test_file], ["-exf"])
-            run.main([test_file], ["-exs"])
-            run.main([test_file], ["--export_as_clip_sequence"])
+            results.add(run.main([test_file], ["-exf"]))
+            results.add(run.main([test_file], ["-exs"]))
+            results.add(run.main([test_file], ["--export_as_clip_sequence"]))
             run.main([test_file], ["--stats"])
 
         return tuple(results)
@@ -577,7 +555,7 @@ def main(sys_args: list[str] | None = None):
     def motion():
         out = run.main(
             ["resources/only-video/man-on-green-screen.mp4"],
-            ["--edit", "motion", "--margin", "0", "-mcut", "0", "-mclip", "0"],
+            ["--edit", "motion", "--margin", "0"],
         )
         out2 = run.main(
             ["resources/only-video/man-on-green-screen.mp4"],
@@ -601,11 +579,11 @@ def main(sys_args: list[str] | None = None):
     def edit_negative_tests():
         run.check(
             ["resources/wav/example-cut-s16le.wav", "--edit", "motion"],
-            "Video stream '0' does not exist",
+            "video stream '0' does not ",
         )
         run.check(
             ["resources/only-video/man-on-green-screen.gif", "--edit", "audio"],
-            "Audio stream '0' does not exist",
+            "audio stream '0' does not ",
         )
 
     def yuv442p():
@@ -618,164 +596,228 @@ def main(sys_args: list[str] | None = None):
 
         return out
 
-    def inter():
-        def my_try(text: str, expected: Any) -> Any:
-            try:
-                lexer = Lexer(text)
-                parser = Parser(lexer)
-                interpreter = Interpreter(parser, None)
-                interpreter.GLOBAL_SCOPE["timebase"] = Fraction(30)
-                results = interpreter.interpret()
-            except MyError as e:
-                raise ValueError(f"{text}\nMyError: {e}")
+    def palet():
+        def cases(*cases: tuple[str, Any]) -> None:
+            for text, expected in cases:
+                try:
+                    parser = Parser(Lexer(text))
+                    env["timebase"] = Fraction(30)
+                    results = interpret(env, parser)
+                except MyError as e:
+                    raise ValueError(f"{text}\nMyError: {e}")
 
-            if isinstance(expected, np.ndarray):
-                if not np.array_equal(expected, results[-1]):
-                    raise ValueError(f"{text}: Numpy arrays don't match")
-            elif expected != results[-1]:
-                raise ValueError(f"{text}: Expected: {expected}, got {results[-1]}")
+                if isinstance(expected, np.ndarray):
+                    if not np.array_equal(expected, results[-1]):
+                        raise ValueError(f"{text}: Numpy arrays don't match")
+                elif expected != results[-1]:
+                    raise ValueError(f"{text}: Expected: {expected}, got {results[-1]}")
 
-        my_try("345", 345)
-        my_try("238.5", 238.5)
-        my_try("-34", -34)
-        my_try("-98.3", -98.3)
-        my_try("+3i", 3j)
-        my_try("3sec", 90)
-        my_try("-3sec", -90)
-        my_try("0.2sec", 6)
-        my_try("(+ 4 3)", 7)
-        my_try("(+ 4 3 2)", 9)
-        my_try("(+ 10.5 3)", 13.5)
-        my_try("(+ 3+4i -2-2i)", 1 + 2j)
-        my_try("(+ 3+4i -2-2i 5)", 6 + 2j)
-        my_try("(- 4 3)", 1)
-        my_try("(- 3)", -3)
-        my_try("(- 10.5 3)", 7.5)
-        my_try("(* 11.5 3)", 34.5)
-        my_try("(/ 3/4 4)", Fraction(3, 16))
-        my_try("(/ 5)", Fraction(1, 5))
-        my_try("(/ 6 1)", 6)
-        my_try("(sqrt -4)", 2j)
-        my_try("(expt 2 3)", 8)
-        my_try("(expt 4 0.5)", 2.0)
-        my_try("(abs 1.0)", 1.0)
-        my_try("(abs -1)", 1)
-        my_try("(boolean? -4)", False)
-        my_try("(boolean? false)", True)
-        my_try("(boolean? #t)", True)
-        my_try("(integer? 3.0)", True)
-        my_try("(integer? 4/5)", False)
-        my_try("(exact? 3.0)", False)
-        my_try("(exact? 3)", True)
-        my_try('(string-append "Hello" " World")', "Hello World")
-        my_try('(define apple "Red Wood") apple', "Red Wood")
-        my_try("(= 1 1.0)", True)
-        my_try("(= 1 2)", False)
-        my_try("(= 2+3i 2+3i 2+3i)", True)
-        my_try("(= 1)", True)
-        my_try("(+)", 0)
-        my_try("(*)", 1)
-        my_try('(define num 13) ; Set number to 13\n"Hello"', "Hello")
-        my_try('(if #t "Hello" apple)', "Hello")
-        my_try('(if #f mango "Hi")', "Hi")
-        my_try('{if (= [+ 3 4] 7) "yes" "no"}', "yes")
-        my_try("((if #t + -) 3 4)", 7)
-        my_try("((if #t + oops) 3+3i 4-2i)", 7 + 1j)
-        my_try("((if #f + -) 3 4)", -1)
-        my_try("(when (positive? 3) 17)", 17)
-        my_try("(string)", "")
-        my_try("(string #\\a)", "a")
-        my_try("(string #\\a #\\b)", "ab")
-        my_try("(string #\\a #\\b #\\c)", "abc")
-        my_try(
-            "(margin 0 (boolarr 0 0 0 1 0 0 0))",
-            np.array([0, 0, 0, 1, 0, 0, 0], dtype=np.bool_),
+        cases(
+            ("345", 345),
+            ("238.5", 238.5),
+            ("-34", -34),
+            ("-98.3", -98.3),
+            ("+3i", 3j),
+            ("3sec", 90),
+            ("-3sec", -90),
+            ("0.2sec", 6),
+            ("(+ 4 3)", 7),
+            ("(+ 4 3 2)", 9),
+            ("(+ 10.5 3)", 13.5),
+            ("(+ 3+4i -2-2i)", 1 + 2j),
+            ("(+ 3+4i -2-2i 5)", 6 + 2j),
+            ("(- 4 3)", 1),
+            ("(- 3)", -3),
+            ("(- 10.5 3)", 7.5),
+            ("(* 11.5 3)", 34.5),
+            ("(/ 3/4 4)", Fraction(3, 16)),
+            ("(/ 5)", Fraction(1, 5)),
+            ("(/ 6 1)", 6),
+            ("30/1", Fraction(30)),
+            ("(sqrt -4)", 2j),
+            ("(pow 2 3)", 8),
+            ("(pow 4 0.5)", 2.0),
+            ("(abs 1.0)", 1.0),
+            ("(abs -1)", 1),
+            ("(round 3.5)", 4),
+            ("(round 2.5)", 2),
+            ("(ceil 2.1)", 3),
+            ("(ceil 2.9)", 3),
+            ("(floor 2.1)", 2),
+            ("(floor 2.9)", 2),
+            ("(bool? #t)", True),
+            ("(bool? #f)", True),
+            ("(bool? 0)", False),
+            ("(bool? 1)", False),
+            ("(bool? false)", True),
+            ("(int? 2)", True),
+            ("(int? 3.0)", False),
+            ("(int? #t)", False),
+            ("(int? #f)", False),
+            ("(int? 4/5)", False),
+            ("(int? 0+2i)", False),
+            ('(int? "hello")', False),
+            ('(int? "3")', False),
+            ("(float? -23.4)", True),
+            ("(float? 3.0)", True),
+            ("(float? #f)", False),
+            ("(float? 4/5)", False),
+            ("(float? 21)", False),
+            ("(frac? 4/5)", True),
+            ("(frac? 3.4)", False),
+            ('(string-append "Hello" " World")', "Hello World"),
+            ('(define apple "Red Wood") apple', "Red Wood"),
+            ("(= 1 1.0)", True),
+            ("(= 1 2)", False),
+            ("(= 2+3i 2+3i 2+3i)", True),
+            ("(= 1)", True),
+            ("(+)", 0),
+            ("(*)", 1),
+            ('(define num 13) ; Set number to 13\n"Hello"', "Hello"),
+            ('(if #t "Hello" apple)', "Hello"),
+            ('(if #f mango "Hi")', "Hi"),
+            ('{if (= [+ 3 4] 7) "yes" "no"}', "yes"),
+            ("((if #t + -) 3 4)", 7),
+            ("((if #t + oops) 3+3i 4-2i)", 7 + 1j),
+            ("((if #f + -) 3 4)", -1),
+            ("(when (positive? 3) 17)", 17),
+            ("(string)", ""),
+            ("(string #\\a)", "a"),
+            ("(string #\\a #\\b)", "ab"),
+            ("(string #\\a #\\b #\\c)", "abc"),
+            (
+                "(margin 0 (bool-array 0 0 0 1 0 0 0))",
+                np.array([0, 0, 0, 1, 0, 0, 0], dtype=np.bool_),
+            ),
+            (
+                "(margin -2 2 (bool-array 0 0 1 1 0 0 0))",
+                np.array([0, 0, 0, 0, 1, 1, 0], dtype=np.bool_),
+            ),
+            ("(count-nonzero (bool-array 0 0 1 1 0 1))", 3),
+            ("(equal? 3 3)", True),
+            ("(equal? 3 3.0)", False),
+            ('(equal? 16.3 "Editor")', False),
+            ("(equal? (bool-array 1 1 0) (bool-array 1 1 0))", True),
+            ("(equal? (bool-array 0 1 0) (bool-array 1 1 0))", False),
+            ("(equal? (bool-array 0 1 0) (bool-array 0 1 0 0))", False),
+            ("(equal? #\\a #\\a)", True),
+            ('(equal? "a" #\\a)', False),
+            ("(equal? (list 1 2 3) (vector 1 2 3))", False),
+            ("(equal? (vector 1 2 3) (vector 1 2 3))", True),
+            ("(equal? (list 1 2 3) (list 1 2 3))", True),
+            ("(equal? (list 1 2 3) (cons 1 (cons 2 (cons 3 '()))))", True),
+            ("(equal? (list 1 2 3) (list 1 2 4))", False),
+            (
+                "(or (bool-array 1 0 0) (bool-array 0 0 0 1))",
+                np.array([1, 0, 0, 1], dtype=np.bool_),
+            ),
+            ("(quote ())", Null),
+            ("'()", Null),
+            ("(quote hello)", Sym("hello")),
+            ("'hello", Sym("hello")),
+            ("(quote (3))", Cons(3, Null)),
+            ("'(3)", Cons(3, Null)),
+            ('(quote (3 2 "apple"))', Cons(3, Cons(2, Cons("apple", Null)))),
+            ('\'(3 2 "apple")', Cons(3, Cons(2, Cons("apple", Null)))),
+            ("(quote +3i)", 3j),
+            ("(quote 23.4)", 23.4),
+            ('(quote "hello")', "hello"),
+            ("(quote (1 (2 3)))", Cons(1, Cons(Cons(2, Cons(3, Null)), Null))),
+            ("(list 1 2 3)", Cons(1, Cons(2, Cons(3, Null)))),
+            ("(list-ref '(0 10 20) 2)", 20),
+            ("(list-ref '(0 10 20) 0)", 0),
+            ("(car (cons 3 4))", 3),
+            ("(car (list 3 4))", 3),
+            ("(cdr (cons 3 4))", 4),
+            ("(cdr (list 3 4))", Cons(4, Null)),
+            ("(length (list 1 2 3))", 3),
+            ("(length '(1 2 3))", 3),
+            ("(length (vector 1 2 4))", 3),
+            ("(length (list))", 0),
+            ("(length '())", 0),
+            ("(length (bool-array 0 1 0))", 3),
+            ("(equal? (reverse '(0 1 2)) '(2 1 0))", True),
+            ("(equal? (reverse (vector 0 1 2)) (vector 2 1 0))", True),
+            ('(ref "Zyx" 1)', Char("y")),
+            ("(ref (vector 0.3 #\\a 2) 2)", 2),
+            ("(ref (range 0 10) 2)", 2),
+            ("((range 0 10) 2)", 2),
+            ("((vector 0.3 #\\a 17) 2)", 17),
+            ("(begin)", None),
+            ("(void)", None),
+            ("(begin (define r 10) (* pi (* r r)))", 314.1592653589793),
+            ("(for/vector ([i (vector 0 1 2)]) i)", [0, 1, 2]),
+            ("(vector -20dB 0dB 20dB)", [0.1, 1, 10]),
+            ("(define ca (lambda (r) (* pi (* r r)))) (ca 5)", 78.53981633974483),
+            (
+                "(define ca (lambda (r) (void) (* pi (* r r)))) (ca 5)",
+                78.53981633974483,
+            ),
+            ("(define (my-pow2 a) (* a a)) (my-pow2 30)", 900),
+            ("(define (my-pow2 a) (void) (* a a)) (my-pow2 30)", 900),
+            ("(cond)", None),
+            ("(cond [(positive? -5) 1])", None),
+            ("(cond [(positive? 5) 3])", 3),
+            ("(cond [(positive? 5)])", True),
+            ("(cond [(positive? -5) 1] [else 2])", 2),
+            ("(cond [(positive? -5) 1] [(zero? -5) 2] [(negative? -5) 3])", 3),
+            ("(cond [else 5])", 5),
+            ("(~a 3 4 'a)", "34a"),
+            ("(~s 3 4 'a)", "3 4 a"),
+            ("(~v 3 4 'a)", "3 4 'a"),
+            ("(eval 3)", 3),
+            ('(eval "hello")', "hello"),
+            ("(eval '(+ 3 4))", 7),
+            ("(eval (list + 3 4))", 7),
+            ("(eval (vector + 3 4))", 7),
+            ("(define (my-func x) (define (inner) 4) (+ x (inner))) (my-func 16)", 20),
+            ("(var-exists? 'my-func)", True),
+            ("(var-exists? 'asdf)", False),
+            ("(define (text child ...) child)", None),
+            ("(text)", []),
+            ("(text 1)", [1]),
+            ("(text 2 1)", [2, 1]),
+            ("(text 3 2 1)", [3, 2, 1]),
+            ("((or/c 0 1) 1)", True),
+            ("((or/c 0 1) 2)", False),
+            ("((or/c 0 1) 1)", True),
+            ('((or/c 0 1 string?) "hello")', True),
+            ("((or/c 0 1 string?) 3)", False),
         )
-        my_try(
-            "(margin -2 2 (boolarr 0 0 1 1 0 0 0))",
-            np.array([0, 0, 0, 0, 1, 1, 0], dtype=np.bool_),
-        )
-        my_try("(count-nonzero (boolarr 0 0 1 1 0 1))", 3)
-        my_try("(equal? 3 3)", True)
-        my_try("(equal? 3 3.0)", False)
-        my_try('(equal? 16.3 "Editor")', False)
-        my_try("(equal? (boolarr 1 1 0) (boolarr 1 1 0))", True)
-        my_try("(equal? (boolarr 0 1 0) (boolarr 1 1 0))", False)
-        my_try("(equal? (boolarr 0 1 0) (boolarr 0 1 0 0))", False)
-        my_try("(equal? #\\a #\\a)", True)
-        my_try('(equal? "a" #\\a)', False)
-        my_try("(equal? (list 1 2 3) (vector 1 2 3))", False)
-        my_try("(equal? (vector 1 2 3) (vector 1 2 3))", True)
-        my_try("(equal? (list 1 2 3) (list 1 2 3))", True)
-        my_try("(equal? (list 1 2 3) (cons 1 (cons 2 (cons 3 '()))))", True)
-        my_try("(equal? (list 1 2 3) (list 1 2 4))", False)
-        my_try(
-            "(or (boolarr 1 0 0) (boolarr 0 0 0 1))",
-            np.array([1, 0, 0, 1], dtype=np.bool_),
-        )
-
-        my_try("(list 1 2 3)", ConsType(1, ConsType(2, ConsType(3, Null()))))
-        my_try("(list-ref (list 0 10 20) 2)", 20)
-        my_try("(list-ref (list 0 10 20) 0)", 0)
-        my_try("(car (cons 3 4))", 3)
-        my_try("(car (list 3 4))", 3)
-        my_try("(cdr (cons 3 4))", 4)
-        my_try("(cdr (list 3 4))", ConsType(4, Null()))
-        my_try("'()", Null())
-        my_try("(length (list 1 2 3))", 3)
-        my_try("(length (list))", 0)
-        my_try("(length (boolarr 0 1 0))", 3)
-        my_try("(begin)", None)
-        my_try("(begin (define r 10) (* pi (* r r)))", 314.1592653589793)
-
-        my_try("(quote ())", Null())
-        my_try("(quote (3))", ConsType(3, Null()))
-        my_try(
-            '(quote (3 2 "apple"))', ConsType(3, ConsType(2, ConsType("apple", Null())))
-        )
-        my_try("(quote +3i)", 3j)
-        my_try("(quote 23.4)", 23.4)
-        my_try('(quote "hello")', "hello")
-        my_try("(for/vector ([i (vector 0 1 2)]) i)", [0, 1, 2])
 
     tests = []
 
-    if args.category in ("unit", "all"):
-        tests.append(inter)
-
-    if args.category in ("api", "all"):
-        tests.append(read_api_0_1)
+    if args.category in ("palet", "all"):
+        tests.append(palet)
 
     if args.category in ("sub", "all"):
-        tests.extend([info, levels, subdump, grep, desc])
+        tests.extend([info, levels, subdump, desc])
 
     if args.category in ("cli", "all"):
         tests.extend(
             [
-                add_audio,
-                video_speed,
-                expand_chunks,
                 SAR,
                 yuv442p,
-                obj_makes_video,
-                edit_positive_tests,
+                check_font_error,
                 edit_negative_tests,
+                edit_positive_tests,
+                json_tests,
+                high_speed_test,
+                video_speed,
+                obj_makes_video,
                 multi_track_edit,
                 concat_mux_tracks,
                 concat_multiple_tracks,
                 render_video_objs,
-                resolution_and_scale,
                 various_errors,
                 render_text,
-                check_font_error,
+                add_audio,
                 frame_rate,
                 help_tests,
                 version_test,
                 parser_test,
                 concat,
                 example,
-                export,
-                high_speed_test,
                 units,
                 sr_units,
                 backwards_range,
@@ -788,9 +830,10 @@ def main(sys_args: list[str] | None = None):
                 progress,
                 silent_threshold,
                 track_tests,
-                json_tests,
                 codec_tests,
                 motion,
+                export,
+                resolution_and_scale,
             ]
         )
 
