@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import sys
 from datetime import timedelta
+from pathlib import Path
 from shutil import get_terminal_size, rmtree
 from time import perf_counter, sleep
 from typing import NoReturn
@@ -10,7 +11,7 @@ from typing import NoReturn
 class Timer:
     __slots__ = ("start_time", "quiet")
 
-    def __init__(self, quiet: bool = False) -> None:
+    def __init__(self, quiet: bool = False):
         self.start_time = perf_counter()
         self.quiet = quiet
 
@@ -27,7 +28,7 @@ class Log:
 
     def __init__(
         self, show_debug: bool = False, quiet: bool = False, temp: str | None = None
-    ) -> None:
+    ):
         self.is_debug = show_debug
         self.quiet = quiet
         self.temp = temp
@@ -50,8 +51,8 @@ class Log:
             try:
                 rmtree(self.temp)
                 self.debug("Removed Temp Directory.")
-            except Exception:
-                self.debug("Failed to delete temp dir.")
+            except Exception as e:
+                self.debug(f"Failed to delete temp dir:\n{e}")
 
     def conwrite(self, message: str) -> None:
         if not self.quiet:
@@ -59,9 +60,11 @@ class Log:
             sys.stdout.write(f"  {message}{buffer}\r")
 
     def error(self, message: str | Exception) -> NoReturn:
+        if self.is_debug and isinstance(message, Exception):
+            self.cleanup()
+            raise message
+
         self.conwrite("")
-        # if isinstance(message, Exception):
-        #     raise message
         sys.stderr.write(f"Error! {message}\n")
         self.cleanup()
         from platform import system
@@ -76,6 +79,9 @@ class Log:
 
                 os._exit(1)
 
+    def nofile(self, path: str | Path) -> NoReturn:
+        self.error(f"Could not find '{path}'")
+
     def warning(self, message: str) -> None:
         if not self.quiet:
             self.conwrite("")
