@@ -3,15 +3,19 @@ from __future__ import annotations
 import re
 from dataclasses import dataclass, field
 from fractions import Fraction
-from typing import Literal, Tuple, Type, Union
+from typing import Literal, Union
+
+
+class CoerceError(Exception):
+    pass
 
 
 def _comma_coerce(name: str, val: str, num_args: int) -> list[str]:
     vals = val.strip().split(",")
     if num_args > len(vals):
-        raise TypeError(f"Too few arguments for {name}.")
+        raise CoerceError(f"Too few arguments for {name}.")
     if len(vals) > num_args:
-        raise TypeError(f"Too many arguments for {name}.")
+        raise CoerceError(f"Too many arguments for {name}.")
     return vals
 
 
@@ -29,24 +33,24 @@ def _split_num_str(val: str | float) -> tuple[float, str]:
     try:
         float(num)
     except ValueError:
-        raise TypeError(f"Invalid number: '{val}'")
+        raise CoerceError(f"Invalid number: '{val}'")
     return float(num), unit
 
 
 def _unit_check(unit: str, allowed_units: tuple[str, ...]) -> None:
     if unit not in allowed_units:
-        raise TypeError(f"Unknown unit: '{unit}'")
+        raise CoerceError(f"Unknown unit: '{unit}'")
 
 
 # Numbers: 0, 1, 2, 3, ...
 def natural(val: str | float) -> int:
     num, unit = _split_num_str(val)
     if unit != "":
-        raise TypeError(f"'{val}': Natural does not allow units.")
-    if num < 0:
-        raise TypeError(f"'{val}': Natural cannot be negative.")
+        raise CoerceError(f"'{val}': Natural does not allow units.")
     if not isinstance(num, int) and not num.is_integer():
-        raise TypeError(f"'{val}': Natural must be an integer.")
+        raise CoerceError(f"'{val}': Natural must be a valid integer.")
+    if num < 0:
+        raise CoerceError(f"'{val}': Natural cannot be negative.")
     return int(num)
 
 
@@ -54,15 +58,17 @@ def number(val: str | float) -> float:
     if isinstance(val, str) and "/" in val:
         nd = val.split("/")
         if len(nd) != 2:
-            raise TypeError(f"'{val}': One divisor allowed.")
+            raise CoerceError(f"'{val}': One divisor allowed.")
         vs = []
         for v in nd:
             try:
                 vs.append(int(v))
             except ValueError:
-                raise TypeError(f"'{val}': Numerator and Denominator must be integers.")
+                raise CoerceError(
+                    f"'{val}': Numerator and Denominator must be integers."
+                )
         if vs[1] == 0:
-            raise TypeError(f"'{val}': Denominator must not be zero.")
+            raise CoerceError(f"'{val}': Denominator must not be zero.")
         return vs[0] / vs[1]
 
     num, unit = _split_num_str(val)
@@ -72,10 +78,27 @@ def number(val: str | float) -> float:
     return num
 
 
+def speed(val: str) -> float:
+    _s = number(val)
+    if _s <= 0 or _s > 99999:
+        return 99999.0
+    return _s
+
+
+def src(val: str) -> int | str:
+    try:
+        if int(val) > 0:
+            return int(val)
+    except ValueError:
+        pass
+
+    return val
+
+
 def threshold(val: str | float) -> float:
     num = number(val)
     if num > 1 or num < 0:
-        raise TypeError(f"'{val}': Threshold must be between 0 and 1 (0%-100%)")
+        raise CoerceError(f"'{val}': Threshold must be between 0 and 1 (0%-100%)")
     return num
 
 
@@ -88,7 +111,7 @@ def frame_rate(val: str) -> Fraction:
         return Fraction(25)
     if val == "film":
         return Fraction(24)
-    return Fraction(number(val))
+    return Fraction(val)
 
 
 def sample_rate(val: str) -> int:
@@ -100,6 +123,14 @@ def sample_rate(val: str) -> int:
 
 
 def time(val: str) -> int | str:
+    if ":" in val:
+        boxes = val.split(":")
+        if len(boxes) == 2:
+            return str(int(boxes[0]) * 60 + float(boxes[1]))
+        if len(boxes) == 3:
+            return str(int(boxes[0]) * 3600 + int(boxes[1]) * 60 + float(boxes[2]))
+        raise CoerceError(f"'{val}': Invalid time format")
+
     num, unit = _split_num_str(val)
     if unit in ("s", "sec", "secs", "second", "seconds"):
         return str(num)
@@ -110,20 +141,18 @@ def time(val: str) -> int | str:
 
     _unit_check(unit, ("",))
     if not isinstance(num, int) and not num.is_integer():
-        raise TypeError(
-            f"'{val}': Time uses ticks by default and ticks doesn't accept non-ints."
-        )
+        raise CoerceError(f"'{val}': Time specifier expects: integer?.")
     return int(num)
 
 
 def anchor(val: str) -> str:
     allowed = ("tl", "tr", "bl", "br", "ce")
     if val not in allowed:
-        raise TypeError("Anchor must be: " + " ".join(allowed))
+        raise CoerceError(f"Anchor must be: {' '.join(allowed)}")
     return val
 
 
-Margin = Tuple[Union[int, str], Union[int, str]]
+Margin = tuple[Union[int, str], Union[int, str]]
 
 
 def margin(val: str) -> Margin:
@@ -131,7 +160,7 @@ def margin(val: str) -> Margin:
     if len(vals) == 1:
         vals.append(vals[0])
     if len(vals) != 2:
-        raise TypeError("--margin has too many arguments.")
+        raise CoerceError("--margin has too many arguments.")
     return time(vals[0]), time(vals[1])
 
 
@@ -154,14 +183,14 @@ def align(val: str) -> Align:
         return "center"
     if val == "right":
         return "right"
-    raise TypeError("Align must be 'left', 'right', or 'center'")
+    raise CoerceError("Align must be 'left', 'right', or 'center'")
 
 
 Stream = Union[int, Literal["all"]]
 
 
 def stream(val: str) -> Stream:
-    if val == "all":
+    if val == "all" or val == "'all":
         return "all"
     return natural(val)
 
@@ -195,7 +224,7 @@ def resolution(val: str | None) -> tuple[int, int] | None:
         return None
     vals = val.strip().split(",")
     if len(vals) != 2:
-        raise TypeError(f"'{val}': Resolution takes two numbers")
+        raise CoerceError(f"'{val}': Resolution takes two numbers")
 
     return natural(vals[0]), natural(vals[1])
 
@@ -209,8 +238,9 @@ def pos(val: tuple[float | str, int]) -> int:
 
 
 @dataclass
-class MainArgs:
+class Args:
     add: list[str] = field(default_factory=list)
+    source: list[str] = field(default_factory=list)
     yt_dlp_location: str = "yt-dlp"
     download_format: str | None = None
     output_format: str | None = None
@@ -234,7 +264,7 @@ class MainArgs:
     background: str = "#000"
     edit_based_on: str = "audio"
     keep_tracks_separate: bool = False
-    export: str = "default"
+    export: str | None = None
     player: str | None = None
     no_open: bool = False
     temp_dir: str | None = None
@@ -243,24 +273,18 @@ class MainArgs:
     progress: str = "modern"
     version: bool = False
     debug: bool = False
-    show_ffmpeg_debug: bool = False
+    show_ffmpeg_commands: bool = False
+    show_ffmpeg_output: bool = False
     quiet: bool = False
     preview: bool = False
-    timeline: bool = False
-    api: str = "1.0.0"
-    frame_margin: Margin = (6, 6)
+    margin: Margin = ("0.2", "0.2")
     silent_speed: float = 99999.0
     video_speed: float = 1.0
-    min_clip_length: int | str = 3
-    min_cut_length: int | str = 6
     output_file: str | None = None
     help: bool = False
     input: list[str] = field(default_factory=list)
 
 
-Args = Type[MainArgs]
-
-
 colormap = {
     # Taken from https://www.w3.org/TR/css-color-4/#named-color
     "aliceblue": "#f0f8ff",
