@@ -4,13 +4,15 @@ import difflib
 import re
 import sys
 import textwrap
+from collections.abc import Iterator
 from dataclasses import dataclass
 from shutil import get_terminal_size
-from typing import Any, Callable, Iterator, Literal, TypeVar, Union
+from typing import Any, Callable, Literal, TypeVar, Union
 
 from auto_editor.utils.log import Log
+from auto_editor.utils.types import CoerceError
 
-T = TypeVar("T", bound=type)
+T = TypeVar("T")
 Nargs = Union[int, Literal["*"]]
 
 
@@ -40,12 +42,9 @@ class OptionText:
 
 
 def indent(text: str, prefix: str) -> str:
-    def predicate(line: str) -> str:
-        return line.strip()
-
     def prefixed_lines() -> Iterator[str]:
         for line in text.splitlines(True):
-            yield (prefix + line if predicate(line) else line)
+            yield (prefix + line if line.strip() else line)
 
     return "".join(prefixed_lines())
 
@@ -95,7 +94,7 @@ def print_program_help(reqs: list[Required], args: list[Options | OptionText]) -
                     width=width,
                     initial_indent=f"{line}{' ' * (split - len(line))}",
                     subsequent_indent=split * " ",
-                ).replace("&", "")
+                )
             else:
                 line += "\n"
                 line += textwrap.fill(
@@ -110,19 +109,6 @@ def print_program_help(reqs: list[Required], args: list[Options | OptionText]) -
     sys.stdout.write(text)
 
 
-def get_help_data() -> dict[str, dict[str, str]]:
-    import json
-    import os.path
-
-    dirpath = os.path.dirname(os.path.realpath(__file__))
-
-    with open(os.path.join(dirpath, "help.json")) as fileobj:
-        data = json.load(fileobj)
-
-    assert isinstance(data, dict)
-    return data
-
-
 def to_underscore(name: str) -> str:
     """Convert new style options to old style.  e.g. --hello-world -> --hello_world"""
     return name[:2] + name[2:].replace("-", "_")
@@ -133,41 +119,33 @@ def to_key(op: Options | Required) -> str:
     return op.names[0][:2].replace("-", "") + op.names[0][2:].replace("-", "_")
 
 
-def print_option_help(program_name: str, ns_obj: T, option: Options) -> None:
+def print_option_help(program_name: str | None, ns_obj: T, option: Options) -> None:
     text = f"  {', '.join(option.names)} {'' if option.metavar is None else option.metavar}\n\n"
 
-    bar_len = 11
     if option.flag:
         text += "    type: flag\n"
-        bar_len = 15
     else:
         if option.nargs != 1:
-            _add = f"    nargs: {option.nargs}\n"
-            bar_len = len(_add)
-            text += _add
+            text += f"    nargs: {option.nargs}\n"
 
-        default: str | None = None
+        default: str | float | int | tuple | None = None
         try:
             default = getattr(ns_obj, to_key(option))
         except AttributeError:
             pass
 
-        if default is not None:
-            if isinstance(default, tuple):
-                _add = f"    default: {','.join(map(str, default))}\n"
-            else:
-                _add = f"    default: {default}\n"
-            bar_len = len(_add)
-            text += _add
+        if default is not None and isinstance(default, (int, float, str)):
+            text += f"    default: {default}\n"
 
         if option.choices is not None:
-            text += "    choices: " + ", ".join(option.choices) + "\n"
+            text += f"    choices: {', '.join(option.choices)}\n"
 
-    text += f"    {'-' * (bar_len - 5)}\n\n    {option.help}\n\n"
-    data = get_help_data()
+    from auto_editor.help import data
 
-    if option.names[0] in data[program_name]:
+    if program_name is not None and option.names[0] in data[program_name]:
         text += indent(data[program_name][option.names[0]], "    ") + "\n"
+    else:
+        text += f"    {option.help}\n\n"
 
     out(text)
 
@@ -185,32 +163,32 @@ def parse_value(option: Options | Required, val: str | None) -> Any:
 
     try:
         value = option.type(val)
-    except TypeError as e:
+    except CoerceError as e:
         Log().error(e)
 
     if option.choices is not None and value not in option.choices:
-        my_choices = ", ".join(option.choices)
+        choices = ", ".join(option.choices)
 
         Log().error(
-            f"{value} is not a choice for {option.names[0]}\nchoices are:\n  {my_choices}"
+            f"{value} is not a choice for {option.names[0]}\nchoices are:\n  {choices}"
         )
 
     return value
 
 
 class ArgumentParser:
-    def __init__(self, program_name: str) -> None:
+    def __init__(self, program_name: str | None):
         self.program_name = program_name
         self.requireds: list[Required] = []
         self.options: list[Options] = []
         self.args: list[Options | OptionText] = []
 
-    def add_argument(self, *args: str, **kwargs) -> None:
+    def add_argument(self, *args: str, **kwargs: Any) -> None:
         x = Options(args, **kwargs)
         self.options.append(x)
         self.args.append(x)
 
-    def add_required(self, *args: str, **kwargs) -> None:
+    def add_required(self, *args: str, **kwargs: Any) -> None:
         self.requireds.append(Required(args, **kwargs))
 
     def add_text(self, text: str) -> None:
@@ -218,12 +196,14 @@ class ArgumentParser:
 
     def parse_args(
         self,
-        ns_obj: T,
+        ns_obj: type[T],
         sys_args: list[str],
         macros: list[tuple[set[str], list[str]]] | None = None,
     ) -> T:
-        if len(sys_args) == 0:
-            out(get_help_data()[self.program_name]["_"])
+        if not sys_args and self.program_name is not None:
+            from auto_editor.help import data
+
+            out(data[self.program_name]["_"])
             sys.exit()
 
         if macros is not None:
@@ -272,7 +252,7 @@ class ArgumentParser:
                     try:
                         val = oplist_coerce(arg)
                         ns.__setattr__(oplist_name, getattr(ns, oplist_name) + [val])
-                    except (TypeError, ValueError) as e:
+                    except (CoerceError, ValueError) as e:
                         Log().error(e)
                 elif requireds and not arg.startswith("--"):
                     if requireds[0].nargs == 1:
@@ -297,7 +277,9 @@ class ArgumentParser:
             else:
                 if option.nargs != "*":
                     if option in used_options:
-                        Log().error(f"Cannot repeat option {option.names[0]} twice.")
+                        Log().error(
+                            f"Option {option.names[0]} may not be used more than once."
+                        )
                     used_options.append(option)
 
                 oplist_name = None
@@ -323,7 +305,7 @@ class ArgumentParser:
         if setting_req_list:
             ns.__setattr__(req_list_name, req_list)
 
-        if ns.help:
+        if getattr(ns, "help"):
             print_program_help(requireds, args)
             sys.exit()
 
